(acc-checksum-field r [t v])(acc-size-field r [t v])(add-checksum fix-vec)(byte-count s)(checksum msg)Returns a 3-character string (left-padded with zeroes) representing the checksum of msg calculated according to the FIX protocol.
Returns a 3-character string (left-padded with zeroes) representing the checksum of msg calculated according to the FIX protocol.
(checksum2 fields)Returns a 3-character string (left-padded with zeroes) representing the checksum of msg calculated according to the FIX protocol.
Returns a 3-character string (left-padded with zeroes) representing the checksum of msg calculated according to the FIX protocol.
(create-reader items)(create-writer)(decode-header {:keys [header] :as decoder} item-reader)(decode-message decoder fix-vec)(decode-payload decoder [msg-type fix-vec])(decode-payload-type {:keys [header trailer messages] :as decoder}
msg-type
item-reader)(decode-trailer {:keys [trailer] :as decoder} item-reader)(encode-fix-body decoder [msg-type body])(encode-fix-msg decoder fix-msg)(encode-header decoder header)(fix->payload decoder fix-vec)(fix-body-length fields)(get-current reader)(insert-begin-size fix-version header-vec body-vec)(linearize-map decoder {:keys [name content] :as _section} m item-writer)(linearize-vec decoder vec-name fields vec-value item-writer)(more? reader)(move-next reader)(pop-items writer)(read-map {:keys [name content] :as _section} item-reader)(read-vec {:keys [name _content nr] :as section} item-reader)(write writer field)(write-fields2 fields)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |